// --------------------------------------------------------------------------
// External files inclusions.
// --------------------------------------------------------------------------
#include <pic.h>                                                // Use a PIC16F877A.



// --------------------------------------------------------------------------
// EEPROM data storage.
// --------------------------------------------------------------------------
__EEPROM_DATA(0xC0, 0xCF, 0x6A, 0x00,                           // Location where VFO_A_freq is stored (start with 7.000000MHz).
              0x80, 0x9F, 0xD5, 0x00);                          // Location where VFO_B_freq is stored (start with 14.000000MHz).
__EEPROM_DATA(0x09,                                             // Location where VFO_A_step is stored (start with 1kHz).
              0x09,                                             // Location where VFO_B_step is stored (start with 1kHz).
              0x00,                                             // Location where VFO_active is stored (start with VFO_A).
              0, 0, 0, 0, 0);                                   // Not used.
__EEPROM_DATA('H', 'B', '9', 'D', 'U', 'L',' ',' ');            // Not used, just for fun.



// --------------------------------------------------------------------------
// External variables defined in main.c
// --------------------------------------------------------------------------
extern long int VFO_A_freq, VFO_B_freq;                         // Frequencies of both VFOs.
extern signed char VFO_A_step, VFO_B_step;                      // Setp indexes of both VFOs (for VFO_steps).
extern unsigned char VFO_active;                                // VFO_A or VFO_B.



// --------------------------------------------------------------------------
// This procedure loads the configuration stored in the EEPROM into the
// variables VFO_A_freq, VFO_B_freq, VFO_A_step, VFO_B_step and VFO_active.
// --------------------------------------------------------------------------
void EEPROM_load_config(void)
{
    (unsigned char) *(((char*)(&VFO_A_freq))+0) = eeprom_read(0x00);
    (unsigned char) *(((char*)(&VFO_A_freq))+1) = eeprom_read(0x01);
    (unsigned char) *(((char*)(&VFO_A_freq))+2) = eeprom_read(0x02);
    (unsigned char) *(((char*)(&VFO_A_freq))+3) = eeprom_read(0x03);

    (unsigned char) *(((char*)(&VFO_B_freq))+0) = eeprom_read(0x04);
    (unsigned char) *(((char*)(&VFO_B_freq))+1) = eeprom_read(0x05);
    (unsigned char) *(((char*)(&VFO_B_freq))+2) = eeprom_read(0x06);
    (unsigned char) *(((char*)(&VFO_B_freq))+3) = eeprom_read(0x07);

    VFO_A_step = eeprom_read(0x08);
    VFO_B_step = eeprom_read(0x09);
    VFO_active = eeprom_read(0x0A);
}



// --------------------------------------------------------------------------
// This procedure stores the variables VFO_A_freq, VFO_B_freq, VFO_A_step,
// VFO_B_step and VFO_active into the EEPROM.
// --------------------------------------------------------------------------
void EEPROM_save_config(void)
{
    eeprom_write(0x00,(unsigned char) *(((char*)(&VFO_A_freq))+0) );
    eeprom_write(0x01,(unsigned char) *(((char*)(&VFO_A_freq))+1) );
    eeprom_write(0x02,(unsigned char) *(((char*)(&VFO_A_freq))+2) );
    eeprom_write(0x03,(unsigned char) *(((char*)(&VFO_A_freq))+3) );

    eeprom_write(0x04,(unsigned char) *(((char*)(&VFO_B_freq))+0) );
    eeprom_write(0x05,(unsigned char) *(((char*)(&VFO_B_freq))+1) );
    eeprom_write(0x06,(unsigned char) *(((char*)(&VFO_B_freq))+2) );
    eeprom_write(0x07,(unsigned char) *(((char*)(&VFO_B_freq))+3) );

    eeprom_write(0x08,VFO_A_step);
    eeprom_write(0x09,VFO_B_step);
    eeprom_write(0x0A,VFO_active);
}


